/*
 * Interface: DataSource
 *
 * $Id: DataSource.java,v 1.1.1.1 2005/05/22 17:00:49 macias Exp $
 */
package es.rediris.aarr.data;

import java.net.URL;


/** This interface defines the methods that external data sources will
 * have to implement.
 *
 * @author macias */
public interface DataSource {
    /** This method is used to initiate the data source; this may consist
    * in the load of a file, the connection to an LDAP server or an SQL
    * database, or whatever other form of initiating a data retrieving.
    * @throws DataSourceException If there was an error when initting the data source */
    public void init() throws DataSourceException;

    /** Sets a name for the data source.
    @param id A identificator for the data source */
    public void setName(String id);

    /** Gets the name for the data source.
    @return an string with the name of the data source */
    public String getName();

    /** Returns the value for the given key.
    @param key the name of the key
    @return The value for the given key
    @throws DataSourceException If there was a problem retrieving the key from the data source */
    public String getValue(String key) throws DataSourceException;

    /** Returns true if the given key exists in the datasource.
    @param key the name of the key
    @return A boolean balue. True if the key exists, false otherwise
    @throws DataSourceException  If there was a problem when trying to guess if the key exists */
    public boolean exists(String key) throws DataSourceException;
}
