/*
 * Class: ObservableVector
 *
 * $Id: ObservableVector.java,v 1.1.1.1 2005/05/22 17:00:49 macias Exp $
 */
package es.rediris.aarr.data;

import java.util.Observable;
import java.util.Vector;


/**
 * This class extends java.util.Observable. It contains a java.util.Vector and adds
 * 'Observable' characteristics to the Vector
 */
public class ObservableVector extends Observable {
    /** A simple <code>java.util.Vector</code> */
    Vector vector;

    /** Unique constructor. Instantiates a new <code>java.util.Vector</code> */
    public ObservableVector() {
        vector = new Vector();
    }

    /** Adds a new element to the vector,  marks this object as having
    been changed (the hasChanged method will now return true) and notifies
    observers about the change (therefore setting back the Changed status to false)

     @param o the element being added
     */
    public void addElement(Object o) {
        vector.addElement(o);
        setChanged();
        notifyObservers();
    }

    /** Removes an object from the vector,  marks this object as having
    been changed (the hasChanged method will now return true) and notifies
    observers about the change (therefore setting back the Changed status to false)

     @param o the element being added
    */
    public void delElement(Object o) {
        vector.remove(o);
        setChanged();
        notifyObservers();
    }

    /** Removes an element from the vector passing the name of that element, then marks this object as having
      been changed (the hasChanged method will now return true) and notifies
      observers about the change (therefore setting back the Changed status to false)

      @param index the index for that element
     */
    public void delElement(int index) {
        vector.remove(index);
        setChanged();
        notifyObservers();
    }

    /** Removes the first element within the vector
     @return an object with the element that has been removed
    */
    public Object extractFirstElement() {
        return vector.remove(0);
    }

    /** Gets (returns) the element at the given position
    @param index the position of the element to get
    @return the element to be returned
    */
    public Object getElementAt(int index) {
        return vector.get(index);
    }

    /** Returns the size of the vector (number of elements within)

    @return and integer with the number of elements in the vector */
    public int size() {
        return vector.size();
    }
}
