/*
 * Interface: PlaintextDataFile
 *
 * $Id: PlaintextDataFile.java,v 1.1.1.1 2005/05/22 17:00:49 macias Exp $
 */
package es.rediris.aarr.data;

import es.rediris.aarr.Diagnostic;
import es.rediris.aarr.data.DataSourceException;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

import java.net.MalformedURLException;
import java.net.URL;

import java.util.Hashtable;
import java.util.Vector;


/** This class defines a datasource consisting in a plain text file storing
* the data in the form of pairs key,value.
*
* @author macias
*/
public class PlaintextDataFile implements DataSource {
    private Vector keyValues;
    private String name;
    private String filePath;
    private Hashtable values = new Hashtable();

    /** Inits the Data source (load data from file)

    @param id An identificator (name) for this data source
    @param path The path to the file containing the data */
    public PlaintextDataFile(String id, String path) {
        setName(id);
        filePath = path;
    }

    /** Inits the datasource; that is: load and parse the external file and store
    it into the internal has table */
    public void init() throws DataSourceException {
        try {
            File file = new File(filePath);
            FileReader filereader = new FileReader(file);
            BufferedReader reader = new BufferedReader(filereader);

            Diagnostic.writeLog(Diagnostic.INFO_MODE,
                "Loading external data from file '" + filePath + "'.");

            String[] tokenizedValues;

            String linea = reader.readLine();

            while (linea != null) {
                tokenizedValues = linea.split(","); // Separator is a comma
                values.put(tokenizedValues[0], tokenizedValues[1]); // key, value
                linea = reader.readLine();
            }

            Diagnostic.writeLog(Diagnostic.INFO_MODE,
                "Loaded " + values.size() + " keys from file '" + filePath +
                "'.");
        } catch (FileNotFoundException e) {
            Diagnostic.writeLog(Diagnostic.WARNING_MODE,
                "PlaintextDataFile: " + filePath + " was not found. ");
            throw new DataSourceException("File " + filePath +
                " was not found. " + e.getMessage());
        } catch (IOException e) {
            Diagnostic.writeLog(Diagnostic.WARNING_MODE,
                "PlaintextDataFile: IO problem when loading data source from file " +
                filePath + ".");
            throw new DataSourceException(
                "IO problem when loading data source from file " + filePath +
                ".");
        }
    }

    /**  Sets a name for this datasource

    @param id An identificator (name) for this data source */
    public void setName(String id) {
        name = id;
    }

    /**  Gets the name of this datasource

    @return The name of this data source */
    public String getName() {
        return name;
    }

    /** Returns the value for a given key or null if it does not exist in the data source

    @param key A key
    @return The value for the key if it exists within the data source, or false otherwise */
    public String getValue(String key) {
        return (values.containsKey(key)) ? (String) values.get(key) : null;
    }

    /** Returns true if the key exists, false otherwise

    @param key A key
    @return True if key exists, false otherwise */
    public boolean exists(String key) {
        return values.containsKey(key);
    }
}
