/*
 * Class: ActionFinish
 *
 * $Id: ActionFinish.java,v 1.1.1.1 2005/05/22 17:00:49 macias Exp $
 */
package es.rediris.aarr.rules;

import es.rediris.aarr.Diagnostic;

import org.w3c.dom.Element;


/**
 *  This class extends a {@link Action Action} and is used to create and modify
 * Finish Action. This class of action can have three different status values
 * associated: PASS, FAIL, or INCONCLUSIVE.
 *
 * @author kan, macias
 */
public class ActionFinish extends Action {
    /** An <code>String</code> containing the value "pass" */
    public static final String VALUE_PASS = "pass";

    /** An <code>String</code> containing the value "fail" */
    public static final String VALUE_FAIL = "fail";

    /** An <code>String</code> containing the value "inconclusive" */
    public static final String VALUE_INCONCLUSIVE = "inconclusive";

    /** Stores the name for this ActionFinish object */
    String name;

    /** Stores the value for this ActionFinish object */
    String value;

    /** The class constructor sets the name and value of this ActionFinish from the attributes "name" and "finnish"
    of the given condition element
    @param cond A condition (in a <code>org.w3c.dom.Element</code> form */
    public ActionFinish(Element cond) {
        String name = cond.getAttribute("name");

        if (name == null) {
            name = "";
        }

        setName(name);

        String defaultValue = cond.getAttribute("finish");
        setValue(defaultValue);
    }

    /** Gets the name of the actual ActionFinish
    @return A string with the name */
    public String getName() {
        return name;
    }

    /** Sets the name for the actual ActionFinish
    @param name A String containing the new name */
    public void setName(String name) {
        this.name = name;
    }

    /**  Gets the value of the actual ActionFinish
    @return A string with the value */
    public String getValue() {
        return value;
    }

    /** Sets the value for the actual ActionFinish
    @param value A String containing the new value */
    public void setValue(String value) {
        this.value = value;
    }

    /** Executes the action reporting the result to the {@link Diagnostic diagnostics} module.
    @return A null String */
    public String execute() {
        if (getValue().equals(ActionFinish.VALUE_FAIL)) {
            Diagnostic.writeLog(Diagnostic.INFO_MODE,
                "This test is not passed OK");
        } else if (getValue().equals(ActionFinish.VALUE_PASS)) {
            Diagnostic.writeLog(Diagnostic.INFO_MODE, "This test is passed OK");
        } else {
            Diagnostic.writeLog(Diagnostic.INFO_MODE,
                "This test is inconclusive");
        }

        return null;
    }

    /** Always return true for this type of Action

    @return A boolean value (always true for an ActionFinish) */
    public boolean isEndState() {
        return true;
    }
}
