/*
 * Class: ConditionDefault
 *
 * $Id: ConditionDefault.java,v 1.1.1.1 2005/05/22 17:00:49 macias Exp $
 */
package es.rediris.aarr.rules;

import es.rediris.aarr.Diagnostic;

import org.w3c.dom.Element;


/**
*  This class extends a {@link Condition Condition} and is used to create and modify
* a default condition. This class of action can have three different status values
* associated: VALUE_ANY, VALUE_TIMEOUT, and VALUE_EXCEPTION.
*
* @author kan, macias
*/
public class ConditionDefault extends Condition {
    /** An <code>String</code> containing the value "any" */
    public static final String VALUE_ANY = "any";

    /** An <code>String</code> containing the value "timeout" */
    public static final String VALUE_TIMEOUT = "timeout";

    /** An <code>String</code> containing the value "exception" */
    public static final String VALUE_EXCEPTION = "exception";

    /** Stores the name for this ConditionDefault object */
    String name;

    /** Stores the value for this ConditionDefault object */
    String value;

    /** The constructor of this class receives a <code>org.w3c.dom.Element</code> with
    specifying a Condition. It extracts and sets internally the name and default attributes
    from the Condition

    @param cond A <code>org.w3c.dom.Element</code> specifying a condition */
    public ConditionDefault(Element cond) {
        String name = cond.getAttribute("name");

        if (name == null) {
            name = "";
        }

        setName(name);

        String defaultValue = cond.getAttribute("default");
        setValue(defaultValue);
    }

    /** Gets the name of the actual Condition

    @return A string with the name */
    public String getName() {
        return name;
    }

    /** Sets the name for the actual Condition

    @param name A String containing the new name */
    public void setName(String name) {
        this.name = name;
    }

    /** Gets the value of the actual Condition

    @return A string with the value of the condition, one of {@link ConditionDefault#VALUE_ANY VALUE_ANY},
     {@link ConditionDefault#VALUE_TIMEOUT VALUE_TIMEOUT} or {@link ConditionDefault#VALUE_EXCEPTION VALUE_EXCEPTION} */
    public String getValue() {
        return value;
    }

    /** Sets the value of the actual Condition

    @param value A string with the new value of the condition, one of {@link ConditionDefault#VALUE_ANY VALUE_ANY},
     {@link ConditionDefault#VALUE_TIMEOUT VALUE_TIMEOUT} or {@link ConditionDefault#VALUE_EXCEPTION VALUE_EXCEPTION}
    */
    public void setValue(String value) {
        this.value = value;
    }

    /** Always return false since this condition doesn't need a query

    @return A boolean value (always false for a ConditionDefault */
    public boolean needsAQuery() {
        return false;
    }

    /** Checks if the condition is true and matches a {@link ConditionDefault#VALUE_ANY ConditionDefault#VALUE_ANY}
     and then sends output to the  {@link Diagnostic diagnostics} module.

    @return True the value for this condition matches {@link ConditionDefault#VALUE_ANY ConditionDefault#VALUE_ANY}, false otherwise */
    public boolean checkCondition() {
        boolean res = getValue().equals(ConditionDefault.VALUE_ANY);
        String message = "Condition '" + getName() + "' is TRUE";

        if (!res) {
            message = "Default condition returns FALSE";
        }

        Diagnostic.writeLog(Diagnostic.INFO_MODE, message);

        return res;
    }
}
